@@ -21,10 +21,10 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <curses.h>
 #include <assert.h>
-#include <signal.h>
 #include <ctype.h>
+#include <sys/ioctl.h>
+#include <sys/termios.h>
 
 extern "C" {
 #include <config.h>
@@ -45,20 +45,24 @@ void mywerase(WINDOW *win) {
 
 baselist *baselist::signallist= 0;
 void baselist::sigwinchhandler(int) {
+  struct winsize size;
+  if (debug) fprintf(debug,"baselist::sigwinchhandler(), signallist=%p\n",signallist);
   baselist *p= signallist;
   p->enddisplay();
   endwin(); initscr();
+  if (ioctl(fileno(stdout), TIOCGWINSZ, &size) != 0) ohshite(_("ioctl(TIOCGWINSZ) failed"));
+  resizeterm(size.ws_row, size.ws_col); wrefresh(curscr);
   p->startdisplay();
-  if (doupdate() == ERR) ohshite("doupdate in SIGWINCH handler failed");
+  if (doupdate() == ERR) ohshite(_("doupdate in SIGWINCH handler failed"));
 }
 
 static void cu_sigwinch(int, void **argv) {
   struct sigaction *osigactp= (struct sigaction*)argv[0];
   sigset_t *oblockedp= (sigset_t*)argv[1];
   
-  if (sigaction(SIGWINCH,osigactp,0)) ohshite("failed to restore old SIGWINCH sigact");
+  if (sigaction(SIGWINCH,osigactp,0)) ohshite(_("failed to restore old SIGWINCH sigact"));
   delete osigactp;
-  if (sigprocmask(SIG_SETMASK,oblockedp,0)) ohshite("failed to restore old signal mask");
+  if (sigprocmask(SIG_SETMASK,oblockedp,0)) ohshite(_("failed to restore old signal mask"));
   delete oblockedp;
 } 
 
@@ -68,26 +72,26 @@ void baselist::setupsigwinch() {
     
   osigactp= new(struct sigaction);
   oblockedp= new(sigset_t);
-  if (sigprocmask(0,0,oblockedp)) ohshite("failed to get old signal mask");
-  if (sigaction(SIGWINCH,0,osigactp)) ohshite("failed to get old SIGWINCH sigact");
+  if (sigprocmask(0,0,oblockedp)) ohshite(_("failed to get old signal mask"));
+  if (sigaction(SIGWINCH,0,osigactp)) ohshite(_("failed to get old SIGWINCH sigact"));
 
   push_cleanup(cu_sigwinch,~0, 0,0, 2,(void*)osigactp,(void*)oblockedp);
 
-  if (sigprocmask(SIG_BLOCK,&sigwinchset,0)) ohshite("failed to block SIGWINCH");
+  if (sigprocmask(SIG_BLOCK,&sigwinchset,0)) ohshite(_("failed to block SIGWINCH"));
   memset(&nsigact,0,sizeof(nsigact));
   nsigact.sa_handler= sigwinchhandler;
   sigemptyset(&nsigact.sa_mask);
-  nsigact.sa_flags= SA_INTERRUPT;
-  if (sigaction(SIGWINCH,&nsigact,0)) ohshite("failed to set new SIGWINCH sigact");
+//nsigact.sa_flags= SA_INTERRUPT;
+  if (sigaction(SIGWINCH,&nsigact,0)) ohshite(_("failed to set new SIGWINCH sigact"));
 }
 
 void baselist::setheights() {
   int y= ymax - (title_height + colheads_height + thisstate_height);
   assert(y>=1);
-  if (showinfo==2 && y>=3) {
-    list_height= 1;
+  if (showinfo==2 && y>=7) {
+    list_height= 5;
     whatinfo_height= 1;
-    info_height= y-2;
+    info_height= y-6;
   } else if (showinfo==1 && y>=10) {
     list_height= y/2;
     info_height= (y-1)/2;
@@ -114,13 +118,14 @@ void baselist::startdisplay() {
     if (init_pair(1,COLOR_WHITE,COLOR_BLACK) != OK ||
         init_pair(2,COLOR_WHITE,COLOR_RED) != OK ||
         init_pair(3,COLOR_WHITE,COLOR_BLUE) != OK)
-      ohshite("failed to allocate colour pairs");
+      ohshite(_("failed to allocate colour pairs"));
     list_attr= COLOR_PAIR(1);
     listsel_attr= list_attr|A_REVERSE;
     title_attr= COLOR_PAIR(2);
     thisstate_attr= COLOR_PAIR(3);
     selstate_attr= list_attr|A_BOLD;
     selstatesel_attr= listsel_attr|A_BOLD;
+    colheads_attr= COLOR_PAIR(3);
   } else {
     title_attr= A_REVERSE;
     thisstate_attr= A_STANDOUT;
@@ -128,10 +133,11 @@ void baselist::startdisplay() {
     listsel_attr= A_STANDOUT;
     selstate_attr= A_BOLD;
     selstatesel_attr= A_STANDOUT;
+    colheads_attr= A_BOLD;
   }
   query_attr= title_attr;
   info_attr= list_attr;
-  colheads_attr= info_headattr= A_BOLD;
+  info_headattr= A_BOLD;
   whatinfo_attr= thisstate_attr;
 
   // set up windows and pads, based on screen size
@@ -144,30 +150,30 @@ void baselist::startdisplay() {
   setwidths();
   
   titlewin= newwin(1,xmax, 0,0);
-  if (!titlewin) ohshite("failed to create title window");
+  if (!titlewin) ohshite(_("failed to create title window"));
   wattrset(titlewin,title_attr);
   
   whatinfowin= newwin(1,xmax, whatinfo_row,0);
-  if (!whatinfowin) ohshite("failed to create whatinfo window");
+  if (!whatinfowin) ohshite(_("failed to create whatinfo window"));
   wattrset(whatinfowin,whatinfo_attr);
   
   listpad= newpad(nitems+1, total_width);
-  if (!listpad) ohshite("failed to create baselist pad");
+  if (!listpad) ohshite(_("failed to create baselist pad"));
   
   colheadspad= newpad(1, total_width);
-  if (!colheadspad) ohshite("failed to create heading pad");
+  if (!colheadspad) ohshite(_("failed to create heading pad"));
   wattrset(colheadspad,colheads_attr);
   
   thisstatepad= newpad(1, total_width);
-  if (!thisstatepad) ohshite("failed to create thisstate pad");
+  if (!thisstatepad) ohshite(_("failed to create thisstate pad"));
   wattrset(thisstatepad,thisstate_attr);
 
   infopad= newpad(MAX_DISPLAY_INFO, total_width);
-  if (!infopad) ohshite("failed to create info pad");
+  if (!infopad) ohshite(_("failed to create info pad"));
   wattrset(infopad,info_attr);
 
   querywin= newwin(1,xmax,ymax-1,0);
-  if (!querywin) ohshite("failed to create query window");
+  if (!querywin) ohshite(_("failed to create query window"));
 
   if (cursorline >= topofscreen + list_height) topofscreen= cursorline;
   if (topofscreen > nitems - list_height) topofscreen= nitems - list_height;
@@ -179,12 +185,12 @@ void baselist::startdisplay() {
 
   if (debug)
     fprintf(debug,
-            "baselist::startdisplay() done ...\n\n"
+            _("baselist::startdisplay() done ...\n\n"
             " xmax=%d, ymax=%d;\n\n"
             " title_height=%d, colheads_height=%d, list_height=%d;\n"
             " thisstate_height=%d, info_height=%d, whatinfo_height=%d;\n\n"
             " colheads_row=%d, thisstate_row=%d, info_row=%d;\n"
-            " whatinfo_row=%d, list_row=%d;\n\n",
+            " whatinfo_row=%d, list_row=%d;\n\n"),
             xmax, ymax,
             title_height, colheads_height, list_height,
             thisstate_height, info_height, whatinfo_height,
@@ -215,7 +221,7 @@ void baselist::redrawall() {
 }
 
 void baselist::redraw1item(int index) {
-  redraw1itemsel(index, showinfo == 2 ? 0 : index == cursorline);
+  redraw1itemsel(index, index == cursorline);
 }
 
 baselist::baselist(keybindings *kb) {
@@ -235,7 +241,7 @@ baselist::baselist(keybindings *kb) {
 }  
 
 void baselist::itd_keys() {
-  whatinfovb("keybindings");
+  whatinfovb(_("keybindings"));
   
   const int givek= xmax/3;
   bindings->describestart();
@@ -243,7 +249,7 @@ void baselist::itd_keys() {
   while ((ta= bindings->describenext()) != 0) {
     const char **tap= ta+1;
     for (;;) {
-      waddstr(infopad, *tap);
+      waddstr(infopad, gettext(*tap));
       tap++;  if (!*tap) break;
       waddstr(infopad, ", ");
     }
@@ -290,14 +296,14 @@ void baselist::refreshinfo() {
     mywerase(whatinfowin);
     mvwaddstr(whatinfowin,0,0, whatinfovb.string());
     if (infolines > info_height) {
-      wprintw(whatinfowin,"  -- %d%%, press ",
+      wprintw(whatinfowin,_("  -- %d%%, press "),
               (int)((infotopofscreen + info_height) * 100.0 / infolines));
       if (infotopofscreen + info_height < infolines) {
-        wprintw(whatinfowin,"%s for more", bindings->find("iscrollon"));
+        wprintw(whatinfowin,_("%s for more"), bindings->find("iscrollon"));
         if (infotopofscreen) waddstr(whatinfowin, ", ");
       }
       if (infotopofscreen)
-        wprintw(whatinfowin, "%s to go back",bindings->find("iscrollback"));
+        wprintw(whatinfowin, _("%s to go back"),bindings->find("iscrollback"));
       waddch(whatinfowin,'.');
     }
     wnoutrefresh(whatinfowin);
