@@ -1,7 +1,7 @@
-#!/usr/bin/perl
+#! /usr/bin/perl
 
-$dpkglibdir= ".";
-$version= '1.3.6'; # This line modified by Makefile
+$dpkglibdir="/usr/lib/dpkg";
+$version="1.4.1.19"; # This line modified by Makefile
 
 use POSIX;
 use POSIX qw(:errno_h :signal_h);
@@ -104,6 +104,11 @@ for ($i=0;$i<=$#exec;$i++) {
 	    push(@libf,$execf[$i]);
 	    push(@libpaths,$3) if !$libpathadded{$3}++;
 	    $nthisldd++;
+	} elsif (m,^\s+(\S+)\.so\.(\S+)\s+=> not found,) {
+	    push(@libname,$1); push(@libsoname,$2); push(@libpath,$3);
+	    push(@libf,$execf[$i]);
+	    push(@libpaths,$3) if !$libpathadded{$3}++;
+	    $nthisldd++;
 	} else {
 	    &warn("unknown output from ldd on \`$exec[$i]': \`$_'");
 	}
