@@ -52,10 +52,10 @@ if ($ARGV[0] ne 'remove') {
 }
 
 $_ = $ARGV[0];
-if    (/^remove$/)     { &checklinks ("remove"); }
-elsif (/^defaults$/)   { &defaults; &makelinks }
-elsif (/^start|stop$/) { &startstop; &makelinks; }
-else                   { &usage; }
+if    (/^remove$/)       { &checklinks ("remove"); }
+elsif (/^defaults$/)     { &defaults; &makelinks }
+elsif (/^(start|stop)$/) { &startstop; &makelinks; }
+else                     { &usage; }
 
 exit (0);
 
@@ -96,7 +96,7 @@ sub checklinks {
 	}
 	opendir(DIR, ".");
 	foreach $_ (readdir(DIR)) {
-	    next unless (/^[S|K][0-9]*$bn$/);
+	    next unless (/^[S|K]\d\d$bn$/);
 	    $fn = "$etcd$i.d/$_";
 	    $found = 1;
 	    $islnk = &is_link ($_[0], $fn, $bn);
@@ -123,8 +123,8 @@ sub defaults {
     &usage ("defaults takes only one or two codenumbers") if ($#ARGV > 2);
     $start = $stop = $ARGV[1] if ($#ARGV >= 1);
     $stop  =         $ARGV[2] if ($#ARGV >= 2);
-    &usage ("codenumber must be a number")
-	if ($start !~ /^[0-9]+$/ || $stop  !~ /^[0-9]+$/);
+    &usage ("codenumber must be a number between 0 and 99")
+	if ($start !~ /^\d\d?$/ || $stop  !~ /^\d\d?$/);
 
     $start = sprintf("%02d", $start);
     $stop  = sprintf("%02d", $stop);
@@ -149,7 +149,7 @@ sub startstop {
 	    &usage("expected start|stop");
 	}
 
-	if ($ARGV[1] !~ /^[0-9]+$/) {
+	if ($ARGV[1] !~ /^\d\d?$/) {
 	    &usage("expected NN after $ARGV[0]");
 	}
 	$NN = sprintf("%02d", $ARGV[1]);
